
import java.awt.*;
import java.awt.image.*;

/**
 * Class for image shapes.
 */
public class ImageShape extends Shape {
	XYPair topLeft; // top-left corner.
	XYPair botRight; // bottom-right corner.
	BufferedImage img; // The image in this shape.
	
	/**
	 * Constructor:
	 */
	public ImageShape(){
		super();
	}
	
	/**
	 * Constructor:
	 * @param img Image for this shape.
	 * @param x X position of the shape.
	 * @param y Y position of the shape.
	 */
	public ImageShape(BufferedImage img, int x, int y){
		super();
		this.img=img;
		topLeft=new XYPair(x, y);
		pos.add(topLeft);
	}
	
	/**
	 * Constructor:
	 * @param img Image for this shape.
	 * @param x1 X position of the top-left corner.
	 * @param y1 Y position of the top-left corner.
	 * @param x2 X position of the bottom-right corner.
	 * @param y2 Y position of the bottom-right corner.
	 */
	public ImageShape(BufferedImage img, int x1, int y1, int x2, int y2){
		super();
		this.img=img;
		topLeft=new XYPair(x1, y1);
		botRight=new XYPair(x2, y2);
		pos.add(topLeft);
		pos.add(botRight);
	}
	
	/** Paints this shape.
	 * @param g Graphics object to paint on.
	 */
	public void paint(Graphics g){
		if(botRight!=null){
			// bottom right corner is set, so resize the image to fit into the box defined by the 2 corners.
			g.drawImage(img, topLeft.x, topLeft.y, botRight.x, botRight.y, 0, 0,
				img.getWidth()-1, img.getHeight()-1, null);
		}else
			g.drawImage(img, topLeft.x, topLeft.y, null);
	}
	
	/**
	 * Returns the image.
	 * @return The image in the shape.
	 */
	public BufferedImage getImage(){
		return img;
	}
	
	/**
	 * Returns the top-left corner.
	 * @return top-left corner.
	 */
	public XYPair getTopLeft(){
		return topLeft;
	}
	
	/**
	 * Returns the bottom-right corner.
	 * @return bottom-right corner.
	 */
	public XYPair getBottomRight(){
		return botRight;
	}
}
