import java.awt.event.MouseEvent;
import java.util.Vector;


/**
 * Operation for rectangular selectiion.
 */
public class SelectOp implements ICOperation {
	Vector objs;
	ImagePanel imgPanel;
	int regX, regY; // first point of the selection.
	
	/**
	 * Constructor:
	 * @param path Vector of Shape objects that are drawn on the 'imgPanel'
	 * @param imgPanel ImagePanel object to do the selection on.
	 */
	public SelectOp(Vector path, ImagePanel imgPanel){
		objs=path;
		objs.clear();
		this.imgPanel=imgPanel;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mousePressed(java.awt.event.MouseEvent)
	 */
	public boolean mousePressed(MouseEvent e) {
		objs.clear();
		objs.add(new RectSelection(e.getX(), e.getY(), 1, 1));
		regX=e.getX();
		regY=e.getY();
		return true;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mouseReleased(java.awt.event.MouseEvent)
	 */
	public boolean mouseReleased(MouseEvent e) {
		if(objs.size()==1){
			RectSelection r=(RectSelection)objs.elementAt(0);
			if(imgPanel.getImage()==null)
				return false;
			imgPanel.setSelectionX(r.getX());
			imgPanel.setSelectionY(r.getY());
		}
		return false;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mouseEntered(java.awt.event.MouseEvent)
	 */
	public boolean mouseEntered(MouseEvent e) {
		imgPanel.setCursor(Laf.getCursor("crosshair"));
		return false;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mouseExited(java.awt.event.MouseEvent)
	 */
	public boolean mouseExited(MouseEvent e) {
		imgPanel.setCursor(Laf.getCursor("default"));
		return false;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mouseClicked(java.awt.event.MouseEvent)
	 */
	public boolean mouseClicked(MouseEvent e) {
		return false;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mouseMoved(java.awt.event.MouseEvent)
	 */
	public boolean mouseMoved(MouseEvent e) {
		return false;
	}

	/* (non-Javadoc)
	 * @see ICOperation#mouseDragged(java.awt.event.MouseEvent)
	 */
	public boolean mouseDragged(MouseEvent e) {
		if(objs.size()==1){
			RectSelection r=(RectSelection)objs.elementAt(0);
			int x=Math.min(e.getX(), regX), y=Math.min(e.getY(), regY),
				w=Math.abs(e.getX()-regX), h=Math.abs(e.getY()-regY);
			r.setX(x);
			r.setY(y);
			r.setWidth(w);
			r.setHeight(h);
		}
		return true;
	}

	/* (non-Javadoc)
	 * @see ICOperation#beforeDrawing()
	 */
	public void beforeDrawing() {
	}
}
